DateDay class

日模型

Create by JsonYe597232387@qq.com on 2019/12

Inheritance

Constructors

DateDay(int year, int month, [int day = 1])
DateDay.dateTime(DateTime time)
DateDay.now()

Properties

day → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxDays → int
no setterinherited
month → int
no setterinherited
monthEndDay → DateDay
no setterinherited
monthFirstDay → DateDay
no setterinherited
num → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → DateTime
no setterinherited
weekday → int
no setterinherited
year → int
no setterinherited

Methods

add(Duration duration) → DateDay
override
contain(DateDay day) → bool
inherited
copyWith({int? year, int? month, int? day}) → DateDay
override
fourDigits(int n) → String
inherited
inMonth(DateMonth month) → bool
isToday() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(Duration duration) → DateDay
override
toString({String yearSuffix = '-', String monthSuffix = '-', String daySuffix = ''}) → String
A string representation of this object.
override
twoDigits(int n) → String
inherited

Operators

operator <(Object other) → bool
inherited
operator <=(Object other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(Object other) → bool
inherited
operator >=(Object other) → bool
inherited