DateMonth class

月模型

Create by JsonYe597232387@qq.com on 2019/12

Implementers

Constructors

DateMonth(int year, [int month = 1])
DateMonth.dateTime(DateTime time)
DateMonth.now()

Properties

hashCode → int
The hash code for this object.
no setteroverride
maxDays → int
no setter
month → int
no setter
monthEndDay → DateDay
no setter
monthFirstDay → DateDay
no setter
num → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → DateTime
no setter
weekday → int
no setter
year → int
no setter

Methods

add(Duration duration) → DateMonth
contain(DateDay day) → bool
copyWith({int? year, int? month}) → DateMonth
fourDigits(int n) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(Duration duration) → DateMonth
toString({String yearSuffix = '-', String monthSuffix = ''}) → String
A string representation of this object.
override
twoDigits(int n) → String

Operators

operator <(Object other) → bool
operator <=(Object other) → bool
operator ==(Object other) → bool
The equality operator.
override
operator >(Object other) → bool
operator >=(Object other) → bool