MonthWidget<T> class

月视图

Create by JsonYe597232387@qq.com on 2019/12

Inheritance

Constructors

MonthWidget({Key? key, EdgeInsets padding = EdgeInsets.zero, Color color = Colors.transparent, double? width, BuildMark<T>? buildMark, OnDaySelected<T>? onDaySelected, MonthController<T>? controller, BuildWeekHead? buildWeekHead, bool showWeekHead = true, bool showBackground = true, BuildWithMonth? buildMonthBackground, BuildWithDay<T>? buildDayItem, OnContinuousSelectListen? onContinuousSelectListen, ValueChanged<List<DateDay>>? onMultipleSelectListen, bool showMonthHead = true, BuildWithMonth? buildMonthHead, double? height, Color weekHeadColor = Colors.transparent, Color monthHeadColor = Colors.transparent, Color weekColor = const Color(0xa6000000), Color weekendColor = const Color(0xffFF4081), CalendarLocaleType localeType = CalendarLocaleType.zh})
const

Properties

buildDayItem → BuildWithDay<T>?
默认构建日视图
context - 上下文
height - 控件高
width - 控件宽
dayTime - 当前日期
enableSelect - 是否可选
hasMark - 是否含有标记
markData - 标记内容
weekColor - 工作日颜色
weekendColor - 周末颜色
isSelected - 是否被单选
isContinuous - 是否被连选
isMultiple - 是否被多选
buildMark - 自定义构建mark
onDaySelected - 选择事件
final
buildMark → BuildMark<T>?
自定义mark
final
buildMonthBackground → BuildWithMonth?
构建背景
final
buildMonthHead → BuildWithMonth?
构建月视图头部
final
buildWeekHead → BuildWeekHead?
构建星期头部
final
color → Color
面板颜色
final
controller → MonthController<T>?
控制器
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
日历面板高度
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
localeType → CalendarLocaleType
国际化语言类型
final
monthHeadColor → Color
月视图头部背景色
final
onContinuousSelectListen → OnContinuousSelectListen?
连选监听
final
onDaySelected → OnDaySelected<T>?
点击事件
final
onMultipleSelectListen → ValueChanged<List<DateDay>>?
多选监听
final
padding → EdgeInsets
边距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBackground → bool
是否显示背景
final
showMonthHead → bool
是否显示月视图头部
final
showWeekHead → bool
显示星期头部
final
weekColor → Color
工作日字体颜色
final
weekendColor → Color
周末字体颜色
final
weekHeadColor → Color
星期头部背景色
final
width → double?
日历面板宽度
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited